#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0

#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


def update_dimensions(dimensions_base=None, dimensions=None):
    new_dimensions = (dimensions_base or {}).copy()
    new_dimensions.update(dimensions or {})

    return new_dimensions


def update_name(name_base=None, postfix=None):
    if name_base and postfix:
        return "{}.{}".format(name_base, postfix)
    else:
        return name_base or postfix
